﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Data;
using System.Text;
using System.Collections;

namespace WebDataGrid
{
    public static class SampleData
    {
        /// <summary>
        /// Get a table representing a list of colors.
        /// </summary>
        /// <returns></returns>
        public static DataTable GetColorDataTable()
        {

            DataTable dt = new DataTable();

            dt.Columns.Add("ColorId", typeof(int));
            dt.Columns.Add("ColorName", typeof(string));

            dt.Rows.Add(0, "red");
            dt.Rows.Add(1, "orange");
            dt.Rows.Add(2, "yellow");
            dt.Rows.Add(3, "green");
            dt.Rows.Add(4, "blue");
            dt.Rows.Add(5, "indigo");
            dt.Rows.Add(6, "violet");

            return dt;

        }

        /// <summary>
        /// Get a table representing a list of people and their favorite colors
        /// The DataTable returned by this method represents the data returned by a join of the Person table 
        /// and the Color table. In the database, the Person table does not actually have the column FavoriteColorText.        
        /// </summary>
        /// <returns></returns>
        public static DataTable GetPersonDataTable()
        {
            DataTable dt = new DataTable();
            dt.Columns.Add("PersonId", typeof(int));
            dt.Columns.Add("PersonName", typeof(string));
            dt.Columns.Add("ColorId", typeof(int));
            dt.Columns.Add("ColorName", typeof(string));

            dt.Rows.Add(0, "Randy", 0, "red");
            dt.Rows.Add(1, "Omar", 1, "orange");
            dt.Rows.Add(2, "Yuri", 2, "yellow");
            dt.Rows.Add(3, "Gabriel", 3, "green");
            dt.Rows.Add(4, "Bob", 4, "blue");
            dt.Rows.Add(5, "Ishmael", 5, "indigo");
            dt.Rows.Add(6, "Vinny", 6, "violet");
            return dt;
        }

        /// <summary>
        /// Create a string representation of a hash table's keys and values.
        /// This may throw an exception if the keys or values are not strings.
        /// </summary>
        /// <param name="ht"></param>
        /// <returns></returns>
        public static  string HashTableToString(Hashtable ht)
        {
            string result = "";
            StringBuilder sb = new StringBuilder();

            string[] keys = new string[ht.Keys.Count];
            ht.Keys.CopyTo(keys, 0);
            Array.Sort(keys);

            foreach (string key in keys)
            {
                sb.AppendFormat("['{0}'] = '{1}', ", key, ht[key]);
            }
            result = sb.ToString().Substring(0, sb.Length - 2);
            return result;
        }

        public static DataTable PersonTable(string key)
        {
            DataTable value = (DataTable)HttpContext.Current.Session[key];
            if (value == null)
            {
                value = SampleData.GetPersonDataTable();
                HttpContext.Current.Session[key] = value;
            }
            return value;
        }
    }

}